# Copyright (c) 2019 Stephen Bunn <stephen@bunn.io>
# ISC License <https://choosealicense.com/licenses/isc>

# used for referencing metadata in built classes
CONFIG_KEY = "__file_config_metadata"
# used for referencing the custom regex type required for schema building
REGEX_TYPE_NAME = "__file_config_regex"
